.. _output_api:

Output
======
.. autoclass:: sasktran2.OutputIdeal

Base Objects
------------

.. autoclass:: sasktran2.Output


Internal Objects
----------------

.. autoclass:: sasktran2.OutputIdealStokes_1

.. autoclass:: sasktran2.OutputIdealStokes_3
